Color

Struct Color 

pub struct Color { /* private fields */ }
A terminal color.

Implementations

Source

impl Color

pub fn new(color_palette: ColorPalette) -> Color

pub fn new_sp(screen: *mut screen, color_palette: ColorPalette) -> Color

pub unsafe fn set_screen(&mut self, screen: Option<*mut screen>)

Safety

Set the screen of the Color.

Use with caution!!! This function only need’s to be used if using the screen type functions and is provided to allow the alignment of the screen pointer with the screen that the ColorPair are for as this crate will apply a screen of None by default when retriving Attributes from functions such as attr_get() and wattr_get().

pub fn screen(&self) -> Option<*mut screen>

pub fn color_palette(&self) -> ColorPalette

pub fn set_rgb(&self, rgb: RGB) -> Result<(), NCurseswError>

pub fn rgb(&self) -> Result<RGB, NCurseswError>