ChtypeChar

Struct ChtypeChar 

pub struct ChtypeChar { /* private fields */ }
Ascii character and rendition.

Implementations

Source

impl ChtypeChar

pub fn new(ch: AsciiChar) -> ChtypeChar

pub fn from_chtype(raw: u32) -> ChtypeChar

pub fn as_byte(self) -> u8

Converts a Chtype character into a u8.

pub fn as_char(self) -> char

Converts a Chtype character into a char.

pub fn as_ascii_char(self) -> AsciiChar

Converts a Chtype character into a AsciiChar.

pub fn is_alphabetic(self) -> bool

Check if the character is a letter (a-z, A-Z).

pub fn is_digit(self) -> bool

Check if the character is a number (0-9).

pub fn is_alphanumeric(self) -> bool

Check if the character is a letter or number.

pub fn is_blank(self) -> bool

Check if the character is a space or horizontal tab.

pub fn is_whitespace(self) -> bool

Check if the character is a ’ ’, ‘\t’, ‘\n’ or ‘\r’.

pub fn is_control(self) -> bool

Check if the character is a control character.

pub fn get_attributes(self) -> Attributes

Get the attributes of the Chtype character.