pub struct Attributes { /* private fields */ }Expand description
Termianl Attributes.
Implementations
Sourceimpl Attributes
impl Attributes
pub fn new(raw: u32) -> Attributes
pub fn new_sp(screen: *mut screen, raw: u32) -> Attributes
Sourcepub unsafe fn set_screen(&mut self, screen: Option<*mut screen>)
pub unsafe fn set_screen(&mut self, screen: Option<*mut screen>)
Safety
Set the screen pointer of the Attributes.
Use with caution!!! This function only need’s to be used if using the screen type
functions and is provided to allow the alignment of the screen pointer with the
screen that the Attributes are for as this crate will apply a screen of None
by default when retriving Attributes from functions such as attr_get() and
wattr_get().
pub fn is_normal(&self) -> bool
pub fn set_normal(&self) -> Attributes
pub fn is_char_text(&self) -> bool
pub fn set_char_text(&self, enabled: bool) -> Attributes
pub fn is_standout(&self) -> bool
pub fn set_standout(&self, enabled: bool) -> Attributes
pub fn is_underline(&self) -> bool
pub fn set_underline(&self, enabled: bool) -> Attributes
pub fn is_reverse(&self) -> bool
pub fn set_reverse(&self, enabled: bool) -> Attributes
pub fn is_blink(&self) -> bool
pub fn set_blink(&self, enabled: bool) -> Attributes
pub fn is_dim(&self) -> bool
pub fn set_dim(&self, enabled: bool) -> Attributes
pub fn is_bold(&self) -> bool
pub fn set_bold(&self, enabled: bool) -> Attributes
pub fn is_alternate_char_set(&self) -> bool
pub fn set_alternative_char_set(&self, enabled: bool) -> Attributes
pub fn is_invisible(&self) -> bool
pub fn set_invisible(&self, enabled: bool) -> Attributes
pub fn is_protected(&self) -> bool
pub fn set_protected(&self, enabled: bool) -> Attributes
pub fn is_horizontal(&self) -> bool
pub fn set_horizontal(&self, enabled: bool) -> Attributes
pub fn is_left(&self) -> bool
pub fn set_left(&self, enabled: bool) -> Attributes
pub fn is_low(&self) -> bool
pub fn set_low(&self, enabled: bool) -> Attributes
pub fn is_right(&self) -> bool
pub fn set_right(&self, enabled: bool) -> Attributes
pub fn is_top(&self) -> bool
pub fn set_top(&self, enabled: bool) -> Attributes
pub fn is_vertical(&self) -> bool
pub fn set_vertical(&self, enabled: bool) -> Attributes
pub fn is_italic(&self) -> bool
pub fn set_italic(&self, enabled: bool) -> Attributes
Sourceimpl Attributes
impl Attributes
Sourcepub fn color_pair(&self) -> ColorPair
pub fn color_pair(&self) -> ColorPair
Return the ColorPair associated with the Attributes.